@@ -5,13 +5,14 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-12-23'; # DATE
+our $DATE = '2022-12-29'; # DATE
 our $DIST = 'App-CSVUtils'; # DIST
-our $VERSION = '0.999_2'; # TRIAL VERSION
+our $VERSION = '1.000'; # VERSION
 
 use App::CSVUtils qw(
                         gen_csv_util
                         compile_eval_code
+                        eval_code
                 );
 
 gen_csv_util(
@@ -156,14 +157,7 @@ _
         my $r = shift;
 
         my @vals;
-        {
-            local $_ = $r->{wants_input_row_as_hashref} ? $r->{input_row_as_hashref} : $r->{input_row};
-            local $main::row = $r->{input_row};
-            local $main::rownum = $r->{input_rownum};
-            local $main::csv = $r->{input_parser};
-            local $main::fields_idx = $r->{input_fields_idx};
-            eval { @vals = $r->{code}->() };
-        }
+        eval { @vals = eval_code($r->{code}, $r, $r->{wants_input_row_as_hashref} ? $r->{input_row_as_hashref} : $r->{input_row}) };
         die [500, "Error while adding field(s) '".join(",", @{$r->{util_args}{fields}})."' for row #$r->{input_rownum}: $@"]
             if $@;
         if (ref $vals[0] eq 'ARRAY') { @vals = @{ $vals[0] } }
@@ -188,7 +182,7 @@ App::CSVUtils::csv_add_fields - Add one or more fields to CSV file
 
 =head1 VERSION
 
-This document describes version 0.999_2 of App::CSVUtils::csv_add_fields (from Perl distribution App-CSVUtils), released on 2022-12-23.
+This document describes version 1.000 of App::CSVUtils::csv_add_fields (from Perl distribution App-CSVUtils), released on 2022-12-29.
 
 =head1 FUNCTIONS
 
