@@ -5,13 +5,14 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-12-23'; # DATE
+our $DATE = '2022-12-29'; # DATE
 our $DIST = 'App-CSVUtils'; # DIST
-our $VERSION = '0.999_2'; # TRIAL VERSION
+our $VERSION = '1.000'; # VERSION
 
 use App::CSVUtils qw(
                         gen_csv_util
                         compile_eval_code
+                        eval_code
                 );
 
 gen_csv_util(
@@ -65,14 +66,8 @@ _
     on_input_data_row => sub {
         my $r = shift;
 
-        {
-            local $_ = $r->{wants_input_row_as_hashref} ? $r->{input_row_as_hashref} : $r->{input_row};
-            local $main::row = $r->{input_row};
-            local $main::rownum = $r->{input_rownum};
-            local $main::csv = $r->{input_parser};
-            local $main::fields_idx = $r->{input_fields_idx};
-            $r->{code_print_row}->($r->{input_row}) if $r->{code}->($r->{input_row});
-        }
+        $r->{code_print_row}->($r->{input_row})
+            if eval_code($r->{code}, $r, $r->{wants_input_row_as_hashref} ? $r->{input_row_as_hashref} : $r->{input_row});
     },
 );
 
@@ -91,7 +86,7 @@ App::CSVUtils::csv_grep - Only output row(s) where Perl expression returns true
 
 =head1 VERSION
 
-This document describes version 0.999_2 of App::CSVUtils::csv_grep (from Perl distribution App-CSVUtils), released on 2022-12-23.
+This document describes version 1.000 of App::CSVUtils::csv_grep (from Perl distribution App-CSVUtils), released on 2022-12-29.
 
 =head1 FUNCTIONS
 
