@@ -5,13 +5,14 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-12-23'; # DATE
+our $DATE = '2022-12-29'; # DATE
 our $DIST = 'App-CSVUtils'; # DIST
-our $VERSION = '0.999_2'; # TRIAL VERSION
+our $VERSION = '1.000'; # VERSION
 
 use App::CSVUtils qw(
                         gen_csv_util
                         compile_eval_code
+                        eval_code
                 );
 
 gen_csv_util(
@@ -58,17 +59,11 @@ _
     on_input_data_row => sub {
         my $r = shift;
 
-        {
-            local $_ = $r->{input_row}[ $r->{field_idx} ];
-            local $main::row = $r->{input_row};
-            local $main::rownum = $r->{input_rownum};
-            local $main::csv = $r->{input_parser};
-            local $main::fields_idx = $r->{input_fields_idx};
-            eval { $r->{code}->() };
-            die [500, "Error while munging row ".
-                 "#$r->{input_rownum} field '$r->{util_args}{field}' value '$_': $@\n"] if $@;
-            $r->{input_row}->[ $r->{field_idx} ] = $_;
-        }
+        my $topic;
+        eval { $topic = eval_code($r->{code}, $r, $r->{input_row}[$r->{field_idx}], 'return_topic') };
+        die [500, "Error while munging row ".
+             "#$r->{input_rownum} field '$r->{util_args}{field}': $@\n"] if $@;
+        $r->{input_row}->[ $r->{field_idx} ] = $topic;
         $r->{code_print_row}->($r->{input_row});
     },
 );
@@ -88,7 +83,7 @@ App::CSVUtils::csv_munge_field - Munge a field in every row of CSV file with Per
 
 =head1 VERSION
 
-This document describes version 0.999_2 of App::CSVUtils::csv_munge_field (from Perl distribution App-CSVUtils), released on 2022-12-23.
+This document describes version 1.000 of App::CSVUtils::csv_munge_field (from Perl distribution App-CSVUtils), released on 2022-12-29.
 
 =head1 FUNCTIONS
 
